==> haskell-with-location-0.1.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-location.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-location
version:              0.1.0
visibility:           public
id:                   with-location-0.1.0-BGW511NORWz4q38enUbYdy
key:                  with-location-0.1.0-BGW511NORWz4q38enUbYdy
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/with-location#readme
synopsis:
    Use ImplicitParams-based source locations in a backward compatible way

category:             Data
abi:                  5c4d5528da38dad0f36e0dc3e44af95c
exposed:              True
exposed-modules:      Data.WithLocation
import-dirs:          /usr/lib/ghc-8.10.1/site-local/with-location-0.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/with-location-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/with-location-0.1.0
hs-libraries:         HSwith-location-0.1.0-BGW511NORWz4q38enUbYdy
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-with-location/html/with-location.haddock

haddock-html:         /usr/share/doc/haskell-with-location/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-with-location-0.1.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-location.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-location
version:              0.1.0
visibility:           public
id:                   with-location-0.1.0-l1HE7GZ77bKNq1cryVHiU
key:                  with-location-0.1.0-l1HE7GZ77bKNq1cryVHiU
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/with-location#readme
synopsis:
    Use ImplicitParams-based source locations in a backward compatible way

category:             Data
abi:                  9000ef4242273de9d26cacb22793c0e6
exposed:              True
exposed-modules:      Data.WithLocation
import-dirs:          /usr/lib/ghc-8.10.1/site-local/with-location-0.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/with-location-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/with-location-0.1.0
hs-libraries:         HSwith-location-0.1.0-l1HE7GZ77bKNq1cryVHiU
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-with-location/html/with-location.haddock

haddock-html:         /usr/share/doc/haskell-with-location/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
